import React from 'react';
import classnames from 'classnames';
import LRN from '../../vendor/lrn';

export default class ReactInput extends React.Component {
    constructor(props) {
        super(props);

        this.inputStyle = {
            width: props.width,
            height: props.height
        };

        this.suggestedAnswersListRef = React.createRef();
        this.checkAnswerRef = React.createRef();
    }

    componentDidMount() {
        LRN.utils.renderComponent('CheckAnswerButton', this.checkAnswerRef.current);

        if (this.props.showCorrectAnswers) {
            this.setAnswersToSuggestedList();
        }
    }

    componentDidUpdate(prevProps) {
        if (prevProps.showCorrectAnswers !== this.props.showCorrectAnswers) {
            if (this.props.showCorrectAnswers) {
                this.setAnswersToSuggestedList();
            } else if (this.suggestedAnswersListComponent) {
                // Clear current suggsted answer list
                this.suggestedAnswersListComponent.reset();
            }
        }
    }

    setAnswersToSuggestedList() {
        const setAnswers = () => {
            const correctAnswerText = (() => {
                const { validation } = this.props;

                if (validation && validation.valid_response) {
                    return validation.valid_response.value;
                }

                return '';
            })();

            this.suggestedAnswersListComponent.setAnswers([{
                index: 0,
                label: correctAnswerText
            }]);
        };

        if (!this.suggestedAnswersListComponent) {
            LRN.utils.renderComponent('SuggestedAnswersList', this.suggestedAnswersListRef.current)
                .then(component => {
                    this.suggestedAnswersListComponent = component;

                    setAnswers();
                });
        } else {
            setAnswers();
        }
    }

    render() {
        const { disabled, defaultValue, showCorrectAnswers, validationUIVisible, isValid } = this.props;
        const baseClassname = classnames({
            'lrn_response_index_visible': showCorrectAnswers,
            'lrn_correct': validationUIVisible && isValid,
            'lrn_incorrect': validationUIVisible && !isValid
        }, 'input-wrapper');

        return (
            <div>
                <div className={baseClassname}>
                    {validationUIVisible && (
                        <span className="lrn_responseIndex"><span>1</span></span>
                    )}
                    <input type="text" disabled={disabled}
                           style={this.inputStyle} defaultValue={defaultValue}
                           onFocus={this.requestToClearValidationUI}
                           onChange={e => this.notifyChange(e.currentTarget.value)}/>
                    {validationUIVisible && (
                        <span className="lrn_validation_icon"/>
                    )}
                </div>
                <div ref={this.checkAnswerRef}/>
                <div ref={this.suggestedAnswersListRef}/>
            </div>
        );
    }

    notifyChange = LRN._.debounce(value => {
        const { onChange } = this.props;

        onChange && onChange(value);
    });

    requestToClearValidationUI = () => {
        const { requestToClearValidationUI } = this.props;

        requestToClearValidationUI && requestToClearValidationUI();
    };
}
